#
# spec file for package libfabric
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
%define git_ver .0.09aaaf78c239

Name:           libfabric
Summary:        User-space RDMA Fabric Interfaces
License:        GPL-2.0 or BSD-2-Clause
Group:          Development/Libraries/C and C++
Version:        1.5.3
Release:        lp150.2.1
Source:         %{name}-%{version}%{git_ver}.tar.bz2
Source1:        baselibs.conf
Patch0:         libfabric-libtool.patch
Patch1:         prov-verbs-Add-support-of-different-CQ-formats-for-the-verbs-RDM.patch
Url:            http://www.github.com/ofiwg/libfabric
Prefix:         ${_prefix}
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libibverbs-devel
BuildRequires:  libnl3-devel
%ifarch x86_64
BuildRequires:  libpsm2-devel
%endif
%ifarch x86_64 %{ix86}
BuildRequires:  infinipath-psm-devel
%endif
BuildRequires:  fdupes
BuildRequires:  librdmacm-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
%define lib_major 1

%description
libfabric provides a user-space API to access high-performance fabric
services, such as RDMA. This package only contains the fi_info binary.

%package       -n libfabric%{lib_major}
Summary:        Libfabric runtime libary
Group:          System/Libraries

%description -n libfabric%{lib_major}
libfabric provides a user-space API to access high-performance fabric
services, such as RDMA. This package contains the runtime library.


%package        devel
Summary:        Development files for the libfabric library
Group:          Development/Libraries/C and C++
Requires:       libfabric%{lib_major} = %{version}

%description    devel
libfabric provides a user-space API to access high-performance fabric
services, such as RDMA. This package contains the development files.

%prep
%setup -q -n  %{name}-%{version}%{git_ver}
%patch0 -p1
%patch1

%build
rm -f config/libtool.m4
autoreconf -fi
# defaults: with-dlopen and without-valgrind can be over-rode:
%configure %{?_without_dlopen} %{?_with_valgrind} \
	--enable-sockets --enable-verbs --enable-usnic \
%ifarch x86_64 %{ix86}
    --enable-psm \
%endif
%ifarch x86_64
    --enable-psm2 \
%endif
    --disable-static
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install

# remove unpackaged files from the buildroot
rm -f %{buildroot}%{_libdir}/*.la
%fdupes %{buildroot}/%{_prefix}

%post -n libfabric%{lib_major} -p /sbin/ldconfig
%postun -n libfabric%{lib_major} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_bindir}/*
%{_mandir}/man1/*

%files -n libfabric%{lib_major}
%defattr(-,root,root,-)
%{_libdir}/%{name}.so.%{lib_major}*
%doc AUTHORS COPYING README

%files devel
%defattr(-,root,root)
%{_libdir}/%{name}.so
%dir %{_includedir}/rdma
%{_includedir}/rdma/fabric.h
%{_includedir}/rdma/fi_atomic.h
%{_includedir}/rdma/fi_cm.h
%{_includedir}/rdma/fi_domain.h
%{_includedir}/rdma/fi_eq.h
%{_includedir}/rdma/fi_rma.h
%{_includedir}/rdma/fi_endpoint.h
%{_includedir}/rdma/fi_errno.h
%{_includedir}/rdma/fi_tagged.h
%{_includedir}/rdma/fi_trigger.h
%{_includedir}/rdma/fi_ext_usnic.h
%{_mandir}/man3/fi_av.3.gz
%{_mandir}/man3/fi_cm.3.gz
%{_mandir}/man3/fi_cntr.3.gz
%{_mandir}/man3/fi_control.3.gz
%{_mandir}/man3/fi_cq.3.gz
%{_mandir}/man3/fi_domain.3.gz
%{_mandir}/man3/fi_endpoint.3.gz
%{_mandir}/man3/fi_errno.3.gz
%{_mandir}/man3/fi_eq.3.gz
%{_mandir}/man3/fi_fabric.3.gz
%{_mandir}/man3/fi_getinfo.3.gz
%{_mandir}/man3/fi_mr.3.gz
%{_mandir}/man3/fi_msg.3.gz
%{_mandir}/man3/fi_poll.3.gz
%{_mandir}/man3/fi_rma.3.gz
%{_mandir}/man3/fi_tagged.3.gz
%{_mandir}/man3/fi_trigger.3.gz
%{_mandir}/man3/fi_version.3.gz
%{_mandir}/man3/fi_accept.3.gz
%{_mandir}/man3/fi_alias.3.gz
%{_mandir}/man3/fi_atomic.3.gz
%{_mandir}/man3/fi_atomic_valid.3.gz
%{_mandir}/man3/fi_atomicmsg.3.gz
%{_mandir}/man3/fi_atomicv.3.gz
%{_mandir}/man3/fi_av_bind.3.gz
%{_mandir}/man3/fi_av_insert.3.gz
%{_mandir}/man3/fi_av_insertsvc.3.gz
%{_mandir}/man3/fi_av_lookup.3.gz
%{_mandir}/man3/fi_av_open.3.gz
%{_mandir}/man3/fi_av_remove.3.gz
%{_mandir}/man3/fi_av_straddr.3.gz
%{_mandir}/man3/fi_cancel.3.gz
%{_mandir}/man3/fi_close.3.gz
%{_mandir}/man3/fi_cntr_add.3.gz
%{_mandir}/man3/fi_cntr_open.3.gz
%{_mandir}/man3/fi_cntr_read.3.gz
%{_mandir}/man3/fi_cntr_set.3.gz
%{_mandir}/man3/fi_cntr_wait.3.gz
%{_mandir}/man3/fi_compare_atomic.3.gz
%{_mandir}/man3/fi_compare_atomic_valid.3.gz
%{_mandir}/man3/fi_compare_atomicmsg.3.gz
%{_mandir}/man3/fi_compare_atomicv.3.gz
%{_mandir}/man3/fi_connect.3.gz
%{_mandir}/man3/fi_cq_open.3.gz
%{_mandir}/man3/fi_cq_read.3.gz
%{_mandir}/man3/fi_cq_readerr.3.gz
%{_mandir}/man3/fi_cq_readfrom.3.gz
%{_mandir}/man3/fi_cq_sread.3.gz
%{_mandir}/man3/fi_cq_sreadfrom.3.gz
%{_mandir}/man3/fi_cq_strerror.3.gz
%{_mandir}/man3/fi_cq_signal.3.gz
%{_mandir}/man3/fi_domain_bind.3.gz
%{_mandir}/man3/fi_domain_query.3.gz
%{_mandir}/man3/fi_dupinfo.3.gz
%{_mandir}/man3/fi_enable.3.gz
%{_mandir}/man3/fi_ep_bind.3.gz
%{_mandir}/man3/fi_eq_open.3.gz
%{_mandir}/man3/fi_eq_read.3.gz
%{_mandir}/man3/fi_eq_readerr.3.gz
%{_mandir}/man3/fi_eq_sread.3.gz
%{_mandir}/man3/fi_eq_strerror.3.gz
%{_mandir}/man3/fi_eq_write.3.gz
%{_mandir}/man3/fi_fetch_atomic.3.gz
%{_mandir}/man3/fi_fetch_atomic_valid.3.gz
%{_mandir}/man3/fi_fetch_atomicmsg.3.gz
%{_mandir}/man3/fi_fetch_atomicv.3.gz
%{_mandir}/man3/fi_freeinfo.3.gz
%{_mandir}/man3/fi_getname.3.gz
%{_mandir}/man3/fi_getopt.3.gz
%{_mandir}/man3/fi_getpeer.3.gz
%{_mandir}/man3/fi_inject.3.gz
%{_mandir}/man3/fi_injectdata.3.gz
%{_mandir}/man3/fi_inject_atomic.3.gz
%{_mandir}/man3/fi_inject_write.3.gz
%{_mandir}/man3/fi_inject_writedata.3.gz
%{_mandir}/man3/fi_join.3.gz
%{_mandir}/man3/fi_leave.3.gz
%{_mandir}/man3/fi_listen.3.gz
%{_mandir}/man3/fi_mr_bind.3.gz
%{_mandir}/man3/fi_mr_desc.3.gz
%{_mandir}/man3/fi_mr_key.3.gz
%{_mandir}/man3/fi_mr_reg.3.gz
%{_mandir}/man3/fi_mr_regattr.3.gz
%{_mandir}/man3/fi_mr_regv.3.gz
%{_mandir}/man3/fi_open.3.gz
%{_mandir}/man3/fi_open_ops.3.gz
%{_mandir}/man3/fi_passive_ep.3.gz
%{_mandir}/man3/fi_pep_bind.3.gz
%{_mandir}/man3/fi_poll_add.3.gz
%{_mandir}/man3/fi_poll_del.3.gz
%{_mandir}/man3/fi_poll_open.3.gz
%{_mandir}/man3/fi_read.3.gz
%{_mandir}/man3/fi_readmsg.3.gz
%{_mandir}/man3/fi_readv.3.gz
%{_mandir}/man3/fi_recv.3.gz
%{_mandir}/man3/fi_recvmsg.3.gz
%{_mandir}/man3/fi_recvv.3.gz
%{_mandir}/man3/fi_reject.3.gz
%{_mandir}/man3/fi_rx_addr.3.gz
%{_mandir}/man3/fi_rx_size_left.3.gz
%{_mandir}/man3/fi_scalable_ep_bind.3.gz
%{_mandir}/man3/fi_send.3.gz
%{_mandir}/man3/fi_senddata.3.gz
%{_mandir}/man3/fi_sendmsg.3.gz
%{_mandir}/man3/fi_sendv.3.gz
%{_mandir}/man3/fi_setname.3.gz
%{_mandir}/man3/fi_setopt.3.gz
%{_mandir}/man3/fi_shutdown.3.gz
%{_mandir}/man3/fi_strerror.3.gz
%{_mandir}/man3/fi_tinject.3.gz
%{_mandir}/man3/fi_tinjectdata.3.gz
%{_mandir}/man3/fi_tostr.3.gz
%{_mandir}/man3/fi_trecv.3.gz
%{_mandir}/man3/fi_trecvmsg.3.gz
%{_mandir}/man3/fi_trecvv.3.gz
%{_mandir}/man3/fi_tsend.3.gz
%{_mandir}/man3/fi_tsenddata.3.gz
%{_mandir}/man3/fi_tsendmsg.3.gz
%{_mandir}/man3/fi_tsendv.3.gz
%{_mandir}/man3/fi_tx_size_left.3.gz
%{_mandir}/man3/fi_wait.3.gz
%{_mandir}/man3/fi_wait_open.3.gz
%{_mandir}/man3/fi_write.3.gz
%{_mandir}/man3/fi_writedata.3.gz
%{_mandir}/man3/fi_writemsg.3.gz
%{_mandir}/man3/fi_writev.3.gz
%{_mandir}/man3/fi_ep.3.gz
%{_mandir}/man7/fabric.7.gz
%{_mandir}/man7/fi_provider.7.gz
%{_mandir}/man7/fi_direct.7.gz
%{_mandir}/man7/fi_sockets.7.gz
%{_mandir}/man7/fi_verbs.7.gz
%{_mandir}/man7/fi_usnic.7.gz
%ifarch x86_64 %{ix86}
%{_mandir}/man7/fi_psm.7.gz
%endif
%ifarch x86_64
%{_mandir}/man7/fi_psm2.7.gz
%endif
%{_mandir}/man3/fi_trywait.3.gz
%{_mandir}/man7/fi_udp.7.gz

%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Wed Apr 11 2018 nmoreychaisemartin@suse.com
- Add prov-verbs-Add-support-of-different-CQ-formats-for-the-verbs-RDM.patch
  to fix stack smashing when using the verbs provider (bsc#1089190)
* Wed Dec 20 2017 nmoreychaisemartin@suse.com
- Update to v1.5.3
  - Core
  - Handle malloc failures
  - Ensure global lock is initialized on Windows
  - Fix spelling and formatting errors in man pages
  - PSM
  - Fix print format mismatches
  - Remove 15 second startup delay when no hardware is installed
  - Preserve FI_MR_SCALABLE mode bit for backwards compatability
  - PSM2
  - Fix print format mismatches
  - Allow all to all communication between scalable endpoints
  - Preserve FI_MR_SCALABLE mode bit for backwards compatability
  - Fix reference counting issue with opened domains
  - Fix segfault for RMA/atomic operations to local scalable endpoints
  - Fix resource counting related issues for Tx/Rx contexts
  - Allow completion suppression when fi_context is non-NULL
  - Use correct queue for triggered operations with scalable endpoints
  - Sockets
  - Fix check for invalid connection handle
  - Fix crash in fi_av_remove
  - Util
  - Fix number of bits used for connection index
  - Verbs
  - Fix incorrect CQ entry data for MSG endpoints
  - Properly check for errors from getifaddrs
  - Retry getifaddr on failure because of busy netlink sockets
  - Ack CM events on error paths
- Remove 0001-prov-psm-Eliminate-psm2-compat-library-delay-with-hf.patch
  as it was merged upstream
* Mon Nov 20 2017 nmoreychaisemartin@suse.com
- Update to v1.5.2
  - Core
  - Fix Power PC 32-bit build
  - Sockets
  - Fix incorrect reporting of counter attributes
  - Verbs
  - Fix reporting attributes based on device limits
  - Fix incorrect CQ size reported for iWarp NICs
  - Update man page with known issues for specific NICs
  - Fix FI_RX_CQ_DATA mode check
  - Disable on-demand paging by default (can cause data corruption)
  - Disable loopback (localhost) addressing (causing failures in MPI)
* Mon Oct  9 2017 stefan.bruens@rwth-aachen.de
- Fix github issue #3393:
  Add 0001-prov-psm-Eliminate-psm2-compat-library-delay-with-hf.patch
* Thu Oct  5 2017 nmoreychaisemartin@suse.com
- Update to v1.5.1
  - Core
  - Fix initialization used by DL providers to avoid crash
  - Add checks for null hints and improperly terminated strings
  - Check for invalid core names passed to fabric open
  - Provide consistent provider ordering when using DL providers
  - Fix OFI_LIKELY definitions when GNUC is not present
  - GNI
  - Add ability to detect local PE rank
  - Fix compiler/config problems
  - Fix CQ read error corruption
  - Remove tests of deprecated interfaces
  - PSM
  - Fix CQ corruption reporting errors
  - Always generate a completion on error
  - PSM2
  - Fix CQ corruption reporting errors
  - Always generate a completion on error
  - Add checks to handle out of memory errors
  - Add NULL check for iov in atomic readv/writev calls
  - Fix FI_PEEK src address matching
  - Fix bug in scalable endpoint address resolution
  - Fix segfault bug in RMA completion generation
  - Sockets
  - Fix missing FI_CLAIM src address data on completion
  - Fix CQ corruption reporting errors
  - Fix serialization issue wrt out of order CPU writes to Tx ring buffer
  - Verbs
  - Allow modifying rnr retry timout to improve performance
  - Add checks to handle out of memory errors
  - Fix crash using atomic operations for MSG EPs
- Fix dependency to libfabric1 for libfabric-devel in baselibs.conf
* Tue Sep  5 2017 nmoreychaisemartin@suse.com
- Update _service to allow auto updates from github
* Thu Aug 10 2017 nmoreychaisemartin@suse.com
- Update to v1.5.0
  * Authorization keys Authorization keys, commonly referred to as job keys,
    are used to isolate processes from communicating with other processes
    for security purposes.
  * Multicast support Datagram endpoints can now support multicast communication.
  * (Experimental) socket-like endpoint types New FI_SOCK_STREAM and FI_SOCK_DGRAM
    endpoint types are introduced. These endpoint types target support of cloud
    and enterprise based middleware and applications.
  * Tagged atomic support Atomic operations can now target tagged receive
    buffers, in addition to RMA buffers.
  * (Experimental) deferred work queues Deferred work queues are enhanced triggerred
    operations. They target support for collective-based operations.
  * New mode bits: FI_RESTRICTED_COMP and FI_NOTIFY_FLAGS_ONLY These mode bits
    support optimized completion processing to minimize software overhead.
  * Multi-threaded error reporting Reading CQ and EQ errors now allow the application
    to provide the error buffer, eliminating the need for the application to
    synchronize between multiple threads when handling errors.
  * FI_SOURCE_ERR capability This feature allows the provider to validate and
    report the source address for any received messages.
  * FI_ADDR_STR string based addressing Applications can now request and use
    addresses provided using a standardized string format. This makes it easier
    to pass full addressing data through a command line, or handle address exchange
    through text files.
  * Communication scope capabilities: FI_LOCAL_COMM and FI_REMOTE_COMM Used to
    indicate if an application requires communication with peers on the same
    node and/or remote nodes.
  * New memory registration modes The FI_BASIC_MR and FI_SCALABLE_MR memory registration
    modes have been replaced by more refined registration mode bits. This allows
    applications to make better use of provider hardware capabilities when dealing
    with registered memory regions.
  * New mode bit: FI_CONTEXT2 Some providers need more than the size provided by the
    FI_CONTEXT mode bit setting. To accomodate such providers, an FI_CONTEXT2 mode bit
    was added. This mode bit doubles the amount of context space that an application
    allocates on behalf of the provider.
  * PSM provider notes
  * Improve the name server functionality and move to the utility code
  * Handle updated mr_mode definitions
  * Add support of 32 and 64 bit atomic values
  * PSM2 provider notes
  * Add option to adjust the locking level
  * Improve the name server functionality and move to the utility code
  * Add support for string address format
  * Add an environment vaiable for message inject size
  * Handle FI_DISCARD in tagged receive functions
  * Handle updated mr_mode definitions
  * Add support for scalable endpoint
  * Add support of 32 and 64 bit atomic values
  * Add FI_SOURCE_ERR to the supported caps
  * Improve the method of checking device existence
  * Sockets provider notes
  * Updated and enhanced atomic operation support.
  * Add support for experimental deferred work queue operations.
  * Fixed counter signaling when used with wait sets.
  * Improved support on Windows.
  * Cleaned up event reporting for destroyed endpoints.
  * Fixed several possible crash scenarios.
  * Fixed handling socket disconnect events which could hang the provider.
  * UDP provider notes
  * Add support for multicast data transfers
  * Verbs provider notes
  * Fix an issue where if the user requests higher values for tx, rx
    context sizes than default it wasn't honored.
  * Introduce env variables for setting default tx, rx context sizes and iov limits.
  * Report correct completion ordering supported by MSG endpoints.
- Fix rpmbuild warnings
- libfabric-devel requires libfabric1, not libfabric
- Fix baselibs.conf
* Tue Jul  4 2017 nmoreychaisemartin@suse.com
- Enable build on all archs
- Enable mlx build
* Fri Jun 30 2017 nmoreychaisemartin@suse.com
- Add x86 build without libpsm2
* Tue May 16 2017 nmoreychaisemartin@suse.com
- Update to v1.4.2 (bsc#1036907).
* Thu May 11 2017 nmoreychaisemartin@suse.com
- Update to v1.4.2-rc1 (bsc#1036907).
- Update notes:
  - Fix for OS X clock_gettime() portability issue.
  - Updated default counter wait object for improved performance
  - Fix multi-threaded RMA progress stalls
  - Updated default counter wait object for improved performance
  - Fix multi-threaded RMA progress stalls
  - Fix error in fi_cq_sreadfrom aborting before timeout expires
  - Set atomic iov count correct correctly inside fi_atomicv
  - Fix handling of apps that call fork.  Move ibv_fork_init() before
  calling any other verbs call.
  - Fix crash in fi_write when connection is not yet established and
  write data size is below inline threshold.
  - Fix issues not handling multiple ipoib interfaces
  - Reduce lock contention on buffer pools in send/completion handling
  code.
* Wed Apr  5 2017 josef.moellers@suse.com
- This version fixes bnc#990184
  (bnc#990184)
* Thu Mar 23 2017 jengelh@inai.de
- RPM group fix
* Fri Mar 10 2017 josef.moellers@suse.com
- PSM provider notes
  - Defer initialization of the PSM library to allow runtime selection from
    different versions of the same provider before fi_getinfo is called.
- PSM2 provider notes
  - Defer initialization of the PSM2 library to allow runtime selection from
    different versions of the same provider before fi_getinfo is called.
  - General bug fixes.
- UDP provider notes
  - Fix setting address format in fi_getinfo call.
- usNIC provider notes
  - Fixed compilation issues with newer versions of libibverbs.
  (fate#321883)
* Mon Jan 16 2017 ndas@suse.de
- Updated to version 1.4.0 for general stability(fate#321883)
- Summary of changes as follow:
  - Add new options, `-f` and `-d`, to fi_info that can be used to
  specify hints about the fabric and domain name. Change port to `-P`
  and provider to `-p` to be more in line with fi_pingpong.
  * GNI provider notes
  - General bug fixes, plugged memory leaks, performance improvements,
  improved error handling and warning messages, etc.
  - Additional API support:
  - FI_THREAD_COMPLETION
  - FI_RMA_EVENT
  - iov length up to 8 for messaging data transfers
  * PSM provider notes
  - General bug fixes
  - Use utility provider for EQ, wait object, and poll set
  - Allow multi-recv to post buffer larger than message size limit
  * PSM2 provider notes
  - General bug fixes
  - Add support for multi-iov RMA read and aromic operations
  - Allow multi-recv to post buffer larger than message size limit
  * Verbs provider notes
  - Add fork support. It is enabled by default and can be turned off by
  setting the FI_FORK_UNSAFE variable to "yes". This can improve
  performance of memory registrations but also makes fork unsafe. The
  following are the limitations of fork support:
  - Fabric resources like endpoint, CQ, EQ, etc. should not be used in
    the forked process.
  - The memory registered using fi_mr_reg has to be page aligned since
    ibv_reg_mr marks the entire page that a memory region belongs to
    as not to be re-mapped when the process is forked (MADV_DONTFORK).
  - Fix a bug where source address info was not being returned in
  fi_info when destination node is specified.
* Fri May  6 2016 nads@suse.de
- Updated to version 1.3.0 for better PSM2 support as suggested by
  fate#319253, comment #9.
  [*libfabric-libtool.patch]
  Summary of changes as follow:
  * PSM provider notes
  - Remove PSM2 related code.
  * PSM2 provider notes
  - Add support for multi-iov send, tagged send, and RMA write.
  - Use utility provider for EQ, wait object, and poll set.
  * GNI provider notes
  - General bug fixes, plugged memory leaks, etc.
  - Added support for the following APIs:
  - fi_endpoint: fi_getopt, fi_setopt, fi_rx_size_left, fi_tx_size_left, fi_stx_context
  - fi_cq: fi_sread, fi_sreadfrom
  - fi_msg: FI_MULTI_RECV (flag)
  - fi_domain: FI_PROGRESS_AUTO (flag)
  - fi_direct: FI_DIRECT
  - Added support for FI_EP_DGRAM (datagram endpoint):
  - Memory registration improvements:
  - Initial support for Cray Cluster Compatibility Mode (CCM)
  * MXM provider notes
  - Initial release
  * Sockets provider notes
  - Enable FABRIC_DIRECT
  - Enable sockets-provider to run on FreeBSD
  - Add support for fi_trywait
  - Add support for map_addr in shared-av creation
  - Add shared-av support on OSX
  - General bug fixes
  * UDP provider notes
  - Initial release
  * usNIC provider notes
  - Implement fi_recvv and fi_recvmsg for FI_EP_RDM. [PR #1594]
  - Add support for FI_INJECT flag in the FI_EP_RDM implementation of fi_sendv.
  [PR #1594]
  - Handle FI_PEEK flag in fi_eq_sread. [PR #1758]
  - Implement waitsets [PR #1893]
  - Implement fi_trywait [PR #1893]
  - Fix progress thread deadlock [PR #1893]
  - Implement FD based CQ sread [PR #1893]
  * Verbs provider notes
  - Add support for fi_trywait
  - verbs/RDM
  - Add support for RMA operations.
  - Add support for fi_cq_sread and fi_cq_sreadfrom
  - Rework connection management to make it work with fabtests and also allow
    connection to self.
  - Other bug fixes and performance improvements.
* Wed Apr  6 2016 ndas@suse.de
- Moved man pages to main package.
- Fixed invalid library group.
* Wed Apr  6 2016 ndas@suse.de
- Packaging version 1.2.0 for fate#319253
* Fri Feb 12 2016 pth@suse.de
- Use explicit file list instead of wildcards
- Package fi_info.
- Remove libtool.m4 from the package so that autoreconf installs
  a current version.
* Thu Feb 11 2016 pth@suse.de
- Initial package, based on the OFED specfile for libfabric
- Add libfabric-libtool.patch to disable static builds by default.
